@@ -17,8 +17,9 @@ extern const char err_internal[];
 extern const char err_unimpl[];
 extern const char ok[];
 extern const char err_syntax[];
-extern void log(const char* msg);
+extern void logmsg(const char* msg);
 extern void respond(const char*);
+extern void cmd_capa(void);
 
 extern command commands[];
 extern int startup(int argc, char* argv[]);
