@@ -8,6 +8,19 @@ tests_failed=0
 tests_count=0
 _UID=`id -u`
 _GID=`id -g`
+
+usage() {
+  echo "usage: sh $0 [-v]"
+}
+
+vecho() { :; }
+while getopts v flag
+do
+  case $flag in
+    v)      vecho() { echo "$*"; } ;;
+	*)      usage; exit 1 ;;
+  esac
+done
 sfecho() {
   $src/mailfront smtp echo "$@" 2>/dev/null \
   | grep -v '^220 local.host mailfront ESMTP'
@@ -98,6 +111,7 @@ Received: foo
 .
 EOF
 }
+vecho Running test tests/smtpfront-looping-received 
 run_compare_test tests/smtpfront-looping-received  <<END_OF_TEST_RESULTS
 250 Sender='somebody@example.com'.^M
 250 Recipient='nobody@example.org'.^M
@@ -124,18 +138,21 @@ MAIL FROM:<somewhere>
 RCPT TO:<elsewhere>
 EOF
 }
+vecho Running test tests/plugins-remove 'reject'
 run_compare_test tests/plugins-remove 'reject' <<END_OF_TEST_RESULTS
 220 local.host mailfront ESMTP^M
 250 Sender='somewhere'.^M
 250 Recipient='elsewhere'.^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/plugins-remove 'other'
 run_compare_test tests/plugins-remove 'other' <<END_OF_TEST_RESULTS
 220 local.host mailfront ESMTP^M
 451 reject^M
 503 5.5.1 You must send MAIL FROM: first^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/plugins-remove '*'
 run_compare_test tests/plugins-remove '*' <<END_OF_TEST_RESULTS
 220 local.host mailfront ESMTP^M
 250 Sender='somewhere'.^M
@@ -143,6 +160,63 @@ run_compare_test tests/plugins-remove '*' <<END_OF_TEST_RESULTS
 END_OF_TEST_RESULTS
 
 
+##### Test tests/pop3front-maildir-size #####
+
+runtest() {
+maildir
+tstmsg new/1000000000.12345.here
+tstmsg new/1000000001.12345.here,S=1234
+tstmsg new/1000000002.12345.here,W=1234
+tstmsg new/1000000003.12345.here,S=1234,W=2345
+
+echo UIDL | pfmaildir $maildir
+echo LIST | pfmaildir $maildir
+(
+  echo RETR 1
+  echo RETR 2
+  echo RETR 3
+  echo RETR 4
+  echo QUIT
+) | pfmaildir $maildir >/dev/null
+
+ls $maildir/cur
+ls $maildir/new
+echo UIDL | pfmaildir $maildir
+echo LIST | pfmaildir $maildir
+}
+vecho Running test tests/pop3front-maildir-size 
+run_compare_test tests/pop3front-maildir-size  <<END_OF_TEST_RESULTS
++OK ^M
+1 1000000000.12345.here^M
+2 1000000001.12345.here^M
+3 1000000002.12345.here^M
+4 1000000003.12345.here^M
+.^M
++OK ^M
+1 18^M
+2 1234^M
+3 1234^M
+4 2345^M
+.^M
+1000000000.12345.here:2,S
+1000000001.12345.here,S=1234:2,S
+1000000002.12345.here,W=1234:2,S
+1000000003.12345.here,S=1234,W=2345:2,S
++OK ^M
+1 1000000000.12345.here^M
+2 1000000001.12345.here^M
+3 1000000002.12345.here^M
+4 1000000003.12345.here^M
+.^M
++OK ^M
+1 18^M
+2 1234^M
+3 1234^M
+4 2345^M
+.^M
+END_OF_TEST_RESULTS
+
+
 ##### Test tests/rules-noop #####
 
 runtest() {
@@ -161,6 +235,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-noop 
 run_compare_test tests/rules-noop  <<END_OF_TEST_RESULTS
 250 Sender='a@example.com'.^M
 250 Recipient='b@example.net@rc'.^M
@@ -212,6 +287,7 @@ EOF
 
 rm -f $tmp/patterns
 }
+vecho Running test tests/patterns-header 
 run_compare_test tests/patterns-header  <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -225,6 +301,78 @@ run_compare_test tests/patterns-header  <<END_OF_TEST_RESULTS
 END_OF_TEST_RESULTS
 
 
+##### Test tests/pop3front-maildir-numbers #####
+
+runtest() {
+maildir
+cat > $maildir/new/1.2.3 <<EOF
+header
+
+body
+EOF
+
+pfmaildir $maildir <<EOF
+RETR -1
+RETR 0
+RETR 1
+RETR 2
+TOP 1 -1
+TOP 1 0
+TOP 1 1
+UIDL -1
+UIDL 0
+UIDL 1
+UIDL 2
+LIST -1
+LIST 0
+LIST 1
+LIST 2
+DELE -1
+DELE 0
+DELE 1
+DELE 2
+DELE 1
+EOF
+}
+vecho Running test tests/pop3front-maildir-numbers 
+run_compare_test tests/pop3front-maildir-numbers  <<END_OF_TEST_RESULTS
+-ERR Syntax error^M
+-ERR Message number out of range^M
++OK ^M
+header^M
+^M
+body^M
+^M
+.^M
+-ERR Message number out of range^M
+-ERR Syntax error^M
++OK ^M
+header^M
+^M
+^M
+.^M
++OK ^M
+header^M
+^M
+body^M
+^M
+.^M
+-ERR Syntax error^M
+-ERR Message number out of range^M
++OK 1 1.2.3^M
+-ERR Message number out of range^M
+-ERR Syntax error^M
+-ERR Message number out of range^M
++OK 1 13^M
+-ERR Message number out of range^M
+-ERR Syntax error^M
+-ERR Message number out of range^M
++OK ^M
+-ERR Message number out of range^M
+-ERR Message was deleted^M
+END_OF_TEST_RESULTS
+
+
 ##### Test tests/pop3front-auth-userpass #####
 
 runtest() {
@@ -238,6 +386,7 @@ USER testuser
 PASS testpasx
 EOF
 }
+vecho Running test tests/pop3front-auth-userpass 
 run_compare_test tests/pop3front-auth-userpass  <<END_OF_TEST_RESULTS
 +OK ^M
 Yes.
@@ -268,6 +417,7 @@ maildir
 tstmsg new/1000000000.12345.here:1fsd
 pftest 'RETR 1' QUIT
 }
+vecho Running test tests/pop3front-maildir-flags 
 run_compare_test tests/pop3front-maildir-flags  <<END_OF_TEST_RESULTS
 +OK ^M
 Header: foo^M
@@ -327,6 +477,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-databytes2 
 run_compare_test tests/rules-databytes2  <<END_OF_TEST_RESULTS
 250-local.host^M
 250-SIZE 0^M
@@ -388,6 +539,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-both 
 run_compare_test tests/rules-both  <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='a@example.com'.^M
@@ -422,6 +574,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-multiline 
 run_compare_test tests/rules-multiline  <<END_OF_TEST_RESULTS
 250-ONE^M
 250 TWO^M
@@ -443,6 +596,7 @@ MAIL FROM:<somewhere>
 RCPT TO:<elsewhere>
 EOF
 }
+vecho Running test tests/plugin-reject 'rej'
 run_compare_test tests/plugin-reject 'rej' <<END_OF_TEST_RESULTS
 220 local.host mailfront ESMTP^M
 250 local.host^M
@@ -455,6 +609,7 @@ run_compare_test tests/plugin-reject 'rej' <<END_OF_TEST_RESULTS
 503 5.5.1 You must send MAIL FROM: first^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/plugin-reject '-rej'
 run_compare_test tests/plugin-reject '-rej' <<END_OF_TEST_RESULTS
 220 local.host mailfront ESMTP^M
 250 local.host^M
@@ -487,6 +642,7 @@ EOF
 
 unset TMPDIR
 }
+vecho Running test tests/plugin-force-file '/tmp' ''
 run_compare_test tests/plugin-force-file '/tmp' '' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='test@example.com'.^M
@@ -494,6 +650,7 @@ run_compare_test tests/plugin-force-file '/tmp' '' <<END_OF_TEST_RESULTS
 250 Received 128 bytes.^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/plugin-force-file '/tmp' 'force-file'
 run_compare_test tests/plugin-force-file '/tmp' 'force-file' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='test@example.com'.^M
@@ -501,6 +658,7 @@ run_compare_test tests/plugin-force-file '/tmp' 'force-file' <<END_OF_TEST_RESUL
 250 Received 128 bytes.^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/plugin-force-file '/@notmp@' ''
 run_compare_test tests/plugin-force-file '/@notmp@' '' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='test@example.com'.^M
@@ -508,6 +666,7 @@ run_compare_test tests/plugin-force-file '/@notmp@' '' <<END_OF_TEST_RESULTS
 250 Received 128 bytes.^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/plugin-force-file '/@notmp@' 'force-file'
 run_compare_test tests/plugin-force-file '/@notmp@' 'force-file' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='test@example.com'.^M
@@ -542,6 +701,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/imapfront-auth 
 run_compare_test tests/imapfront-auth  <<END_OF_TEST_RESULTS
 1 BAD Syntax error: command requires arguments^M
 2 BAD LOGIN command requires exactly two arguments^M
@@ -580,6 +740,7 @@ bar
 .
 EOF
 }
+vecho Running test tests/smtpfront-content 
 run_compare_test tests/smtpfront-content  <<END_OF_TEST_RESULTS
 250 Sender='user@example.net'.^M
 250 Recipient='user@example.com'.^M
@@ -599,6 +760,7 @@ printf '6:\ntest\n,13:a@example.com,17:13:b@example.com,,' \
 | $src/mailfront qmtp echo 2>/dev/null
 echo
 }
+vecho Running test tests/qmtpfront-echo 
 run_compare_test tests/qmtpfront-echo  <<END_OF_TEST_RESULTS
 18:KReceived 5 bytes.,
 END_OF_TEST_RESULTS
@@ -628,6 +790,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/pop3front-capa 
 run_compare_test tests/pop3front-capa  <<END_OF_TEST_RESULTS
 +OK ^M
 PIPELINING^M
@@ -676,6 +839,7 @@ EOF
 unset CVM_SASL_PLAIN
 unset REQUIRE_AUTH
 }
+vecho Running test tests/smtpfront-require-auth 
 run_compare_test tests/smtpfront-require-auth  <<END_OF_TEST_RESULTS
 530 5.7.1 You must authenticate first.^M
 503 5.5.1 You must send MAIL FROM: first^M
@@ -710,6 +874,7 @@ EOF
 
 unset CVM_LOOKUP CVM_LOOKUP_SECRET
 }
+vecho Running test tests/plugin-cvm-validate 
 run_compare_test tests/plugin-cvm-validate  <<END_OF_TEST_RESULTS
 250 Sender='somewhere'.^M
 250 Recipient='testuser@here'.^M
@@ -726,6 +891,7 @@ END_OF_TEST_RESULTS
 runtest() {
 env SMTPGREETING='hostname hello' $src/mailfront smtp echo 2>/dev/null </dev/null
 }
+vecho Running test tests/smtpgreeting 
 run_compare_test tests/smtpgreeting  <<END_OF_TEST_RESULTS
 220 hostname hello ESMTP^M
 END_OF_TEST_RESULTS
@@ -762,6 +928,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/pop3front-auth-login 
 run_compare_test tests/pop3front-auth-login  <<END_OF_TEST_RESULTS
 -ERR Unrecognized authentication mechanism.^M
 + VXNlcm5hbWU6^M
@@ -807,6 +974,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-selector 
 run_compare_test tests/rules-selector  <<END_OF_TEST_RESULTS
 250 A^M
 250 Recipient='three@example.org'.^M
@@ -829,6 +997,7 @@ USER testuser@adomain
 PASS testpasx
 EOF
 }
+vecho Running test tests/pop3front-auth-split 
 run_compare_test tests/pop3front-auth-split  <<END_OF_TEST_RESULTS
 +OK ^M
 Yes.
@@ -844,6 +1013,7 @@ printf '42:5:test\n,13:a@example.com,13:b@example.com,,' \
 | $src/mailfront qmqp echo 2>/dev/null
 echo
 }
+vecho Running test tests/qmqpfront-echo 
 run_compare_test tests/qmqpfront-echo  <<END_OF_TEST_RESULTS
 18:KReceived 5 bytes.,
 END_OF_TEST_RESULTS
@@ -863,6 +1033,7 @@ tstmsg new/this.is.a.very.long.filename.that.should.get.truncated.after.the.X...
 ) | pfmaildir $maildir
 ( cd $maildir && find new cur -type f | sort )
 }
+vecho Running test tests/pop3front-maildir-state 'false' 'UIDL'
 run_compare_test tests/pop3front-maildir-state 'false' 'UIDL' <<END_OF_TEST_RESULTS
 +OK ^M
 1 1^M
@@ -872,6 +1043,7 @@ new/1
 new/this.is.a.very.long.filename.that.should.get.truncated.after.the.X...XBUGBUGBUGBUG
 END_OF_TEST_RESULTS
 
+vecho Running test tests/pop3front-maildir-state 'false' 'TOP 1 0'
 run_compare_test tests/pop3front-maildir-state 'false' 'TOP 1 0' <<END_OF_TEST_RESULTS
 +OK ^M
 Header: foo^M
@@ -882,6 +1054,7 @@ new/1
 new/this.is.a.very.long.filename.that.should.get.truncated.after.the.X...XBUGBUGBUGBUG
 END_OF_TEST_RESULTS
 
+vecho Running test tests/pop3front-maildir-state 'false' 'RETR 1'
 run_compare_test tests/pop3front-maildir-state 'false' 'RETR 1' <<END_OF_TEST_RESULTS
 +OK ^M
 Header: foo^M
@@ -893,6 +1066,7 @@ new/1
 new/this.is.a.very.long.filename.that.should.get.truncated.after.the.X...XBUGBUGBUGBUG
 END_OF_TEST_RESULTS
 
+vecho Running test tests/pop3front-maildir-state 'true' 'UIDL'
 run_compare_test tests/pop3front-maildir-state 'true' 'UIDL' <<END_OF_TEST_RESULTS
 +OK ^M
 1 1^M
@@ -903,6 +1077,7 @@ cur/1
 cur/this.is.a.very.long.filename.that.should.get.truncated.after.the.X...XBUGBUGBUGBUG
 END_OF_TEST_RESULTS
 
+vecho Running test tests/pop3front-maildir-state 'true' 'TOP 1 0'
 run_compare_test tests/pop3front-maildir-state 'true' 'TOP 1 0' <<END_OF_TEST_RESULTS
 +OK ^M
 Header: foo^M
@@ -914,6 +1089,7 @@ cur/1
 cur/this.is.a.very.long.filename.that.should.get.truncated.after.the.X...XBUGBUGBUGBUG
 END_OF_TEST_RESULTS
 
+vecho Running test tests/pop3front-maildir-state 'true' 'RETR 1'
 run_compare_test tests/pop3front-maildir-state 'true' 'RETR 1' <<END_OF_TEST_RESULTS
 +OK ^M
 Header: foo^M
@@ -945,6 +1121,7 @@ EOF
 
 unset MAXRCPTS
 }
+vecho Running test tests/smtpfront-maxrcpts 
 run_compare_test tests/smtpfront-maxrcpts  <<END_OF_TEST_RESULTS
 250 Sender='notbounce@example.com'.^M
 250 Recipient='addr1@example.net'.^M
@@ -980,6 +1157,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/pop3front-auth-plain 
 run_compare_test tests/pop3front-auth-plain  <<END_OF_TEST_RESULTS
 -ERR Unrecognized authentication mechanism.^M
 -ERR Authentication failed.^M
@@ -1002,6 +1180,7 @@ MAIL FROM:<somewhere>
 RCPT TO:<elsewhere>
 EOF
 }
+vecho Running test tests/plugins-prepend 
 run_compare_test tests/plugins-prepend  <<END_OF_TEST_RESULTS
 220 local.host mailfront ESMTP^M
 451 reject^M
@@ -1043,6 +1222,7 @@ EOF
 
 rm -f $tmp/rules $tmp/list $tmp/atlist
 }
+vecho Running test tests/rules-rcptlist 
 run_compare_test tests/rules-rcptlist  <<END_OF_TEST_RESULTS
 250 Sender='nobody@example.com'.^M
 250 LIST^M
@@ -1082,6 +1262,7 @@ Delivered-To: foo
 .
 EOF
 }
+vecho Running test tests/smtpfront-looping-delivered-to 
 run_compare_test tests/smtpfront-looping-delivered-to  <<END_OF_TEST_RESULTS
 250 Sender='somebody@example.com'.^M
 250 Recipient='nobody@example.org'.^M
@@ -1138,6 +1319,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-databytes3 
 run_compare_test tests/rules-databytes3  <<END_OF_TEST_RESULTS
 250-local.host^M
 250-SIZE 1000^M
@@ -1191,130 +1373,162 @@ DATA
 .
 EOF
 }
+vecho Running test tests/received '' '' '' '' ''
 run_compare_test tests/received '' '' '' '' '' <<END_OF_TEST_RESULTS
 from unknown  by unknown
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' '' '' 'EHLO hh'
 run_compare_test tests/received '' '' '' '' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh  by unknown
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' '' 'li' ''
 run_compare_test tests/received '' '' '' 'li' '' <<END_OF_TEST_RESULTS
 from unknown  by li ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' '' 'li' 'EHLO hh'
 run_compare_test tests/received '' '' '' 'li' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh  by li ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' 'lh' '' ''
 run_compare_test tests/received '' '' 'lh' '' '' <<END_OF_TEST_RESULTS
 from unknown  by lh
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' 'lh' '' 'EHLO hh'
 run_compare_test tests/received '' '' 'lh' '' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh  by lh
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' 'lh' 'li' ''
 run_compare_test tests/received '' '' 'lh' 'li' '' <<END_OF_TEST_RESULTS
 from unknown  by lh ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' 'lh' 'li' 'EHLO hh'
 run_compare_test tests/received '' '' 'lh' 'li' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh  by lh ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' '' '' ''
 run_compare_test tests/received '' 'ri' '' '' '' <<END_OF_TEST_RESULTS
 from ri ([ri])  by unknown
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' '' '' 'EHLO hh'
 run_compare_test tests/received '' 'ri' '' '' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh ([ri])  by unknown
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' '' 'li' ''
 run_compare_test tests/received '' 'ri' '' 'li' '' <<END_OF_TEST_RESULTS
 from ri ([ri])  by li ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' '' 'li' 'EHLO hh'
 run_compare_test tests/received '' 'ri' '' 'li' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh ([ri])  by li ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' 'lh' '' ''
 run_compare_test tests/received '' 'ri' 'lh' '' '' <<END_OF_TEST_RESULTS
 from ri ([ri])  by lh
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' 'lh' '' 'EHLO hh'
 run_compare_test tests/received '' 'ri' 'lh' '' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh ([ri])  by lh
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' 'lh' 'li' ''
 run_compare_test tests/received '' 'ri' 'lh' 'li' '' <<END_OF_TEST_RESULTS
 from ri ([ri])  by lh ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' 'lh' 'li' 'EHLO hh'
 run_compare_test tests/received '' 'ri' 'lh' 'li' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh ([ri])  by lh ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' '' '' ''
 run_compare_test tests/received '' '' '' '' '' <<END_OF_TEST_RESULTS
 from unknown  by unknown
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' '' '' 'EHLO hh'
 run_compare_test tests/received '' '' '' '' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh  by unknown
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' '' 'li' ''
 run_compare_test tests/received '' '' '' 'li' '' <<END_OF_TEST_RESULTS
 from unknown  by li ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' '' 'li' 'EHLO hh'
 run_compare_test tests/received '' '' '' 'li' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh  by li ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' 'lh' '' ''
 run_compare_test tests/received '' '' 'lh' '' '' <<END_OF_TEST_RESULTS
 from unknown  by lh
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' 'lh' '' 'EHLO hh'
 run_compare_test tests/received '' '' 'lh' '' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh  by lh
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' 'lh' 'li' ''
 run_compare_test tests/received '' '' 'lh' 'li' '' <<END_OF_TEST_RESULTS
 from unknown  by lh ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' '' 'lh' 'li' 'EHLO hh'
 run_compare_test tests/received '' '' 'lh' 'li' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh  by lh ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' '' '' ''
 run_compare_test tests/received '' 'ri' '' '' '' <<END_OF_TEST_RESULTS
 from ri ([ri])  by unknown
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' '' '' 'EHLO hh'
 run_compare_test tests/received '' 'ri' '' '' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh ([ri])  by unknown
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' '' 'li' ''
 run_compare_test tests/received '' 'ri' '' 'li' '' <<END_OF_TEST_RESULTS
 from ri ([ri])  by li ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' '' 'li' 'EHLO hh'
 run_compare_test tests/received '' 'ri' '' 'li' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh ([ri])  by li ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' 'lh' '' ''
 run_compare_test tests/received '' 'ri' 'lh' '' '' <<END_OF_TEST_RESULTS
 from ri ([ri])  by lh
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' 'lh' '' 'EHLO hh'
 run_compare_test tests/received '' 'ri' 'lh' '' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh ([ri])  by lh
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' 'lh' 'li' ''
 run_compare_test tests/received '' 'ri' 'lh' 'li' '' <<END_OF_TEST_RESULTS
 from ri ([ri])  by lh ([li])
 END_OF_TEST_RESULTS
 
+vecho Running test tests/received '' 'ri' 'lh' 'li' 'EHLO hh'
 run_compare_test tests/received '' 'ri' 'lh' 'li' 'EHLO hh' <<END_OF_TEST_RESULTS
 from hh ([ri])  by lh ([li])
 END_OF_TEST_RESULTS
@@ -1344,6 +1558,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-databytes 
 run_compare_test tests/rules-databytes  <<END_OF_TEST_RESULTS
 250-local.host^M
 250-SIZE 0^M
@@ -1386,6 +1601,7 @@ EOF
 
 rm -f $tmp/patterns
 }
+vecho Running test tests/patterns-message 
 run_compare_test tests/patterns-message  <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -1434,6 +1650,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/smtpfront-auth-login 
 run_compare_test tests/smtpfront-auth-login  <<END_OF_TEST_RESULTS
 504 Unrecognized authentication mechanism.^M
 250 Sender='user@example.com'.^M
@@ -1467,6 +1684,7 @@ RCPT TO:<him\,himself@example.com>
 RCPT TO:<@somewhere,@elsewhere:two@example.com>
 EOF
 }
+vecho Running test tests/smtpfront-quotes 
 run_compare_test tests/smtpfront-quotes  <<END_OF_TEST_RESULTS
 250 Sender='me, myself, and I@example.net'.^M
 250 Recipient='you, yourself, and you@example.com'.^M
@@ -1492,6 +1710,7 @@ pflast
 mv $maildir/cur/1:2,S $maildir/new/1
 pflast
 }
+vecho Running test tests/pop3front-maildir-last 
 run_compare_test tests/pop3front-maildir-last  <<END_OF_TEST_RESULTS
 +OK 0^M
 +OK 0^M
@@ -1527,6 +1746,7 @@ EOF
 
 rm -f $tmp/patterns
 }
+vecho Running test tests/patterns-normal 
 run_compare_test tests/patterns-normal  <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -1561,6 +1781,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-recip 
 run_compare_test tests/rules-recip  <<END_OF_TEST_RESULTS
 250 Sender='nobody@example.net'.^M
 250 KK^M
@@ -1586,6 +1807,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/pop3front-auth-none 
 run_compare_test tests/pop3front-auth-none  <<END_OF_TEST_RESULTS
 +OK ^M
 .^M
@@ -1622,6 +1844,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-asterisk 
 run_compare_test tests/rules-asterisk  <<END_OF_TEST_RESULTS
 250 K1^M
 250 K2^M
@@ -1654,6 +1877,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/imapfront-auth-plain 
 run_compare_test tests/imapfront-auth-plain  <<END_OF_TEST_RESULTS
 1 NO AUTHENTICATE failed: Authentication failed.^M
 Yes: 2
@@ -1690,6 +1914,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-sender 
 run_compare_test tests/rules-sender  <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 KK^M
@@ -1731,6 +1956,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-maxhops 
 run_compare_test tests/rules-maxhops  <<END_OF_TEST_RESULTS
 250 Sender='a@example.com'.^M
 250 K1^M
@@ -1762,6 +1988,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-empty 
 run_compare_test tests/rules-empty  <<END_OF_TEST_RESULTS
 250 K1^M
 250 K2^M
@@ -1779,6 +2006,7 @@ tstmsg cur/98
 
 echo UIDL | pfmaildir $maildir
 }
+vecho Running test tests/pop3front-maildir-sort 
 run_compare_test tests/pop3front-maildir-sort  <<END_OF_TEST_RESULTS
 +OK ^M
 1 98^M
@@ -1816,6 +2044,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-defaultmsg 
 run_compare_test tests/rules-defaultmsg  <<END_OF_TEST_RESULTS
 553 Rejected^M
 451 Deferred^M
@@ -1883,6 +2112,7 @@ EOF
 unset IMAP_MOVE_EXPUNGE_TO_TRASH
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/imapfront-capability 
 run_compare_test tests/imapfront-capability  <<END_OF_TEST_RESULTS
 * CAPABILITY IMAP4rev1^M
 0 OK CAPABILITY completed^M
@@ -1947,6 +2177,7 @@ EOF
 rm -r $QMAILHOME
 unset QMAILHOME
 }
+vecho Running test tests/plugin-qmail-validate 
 run_compare_test tests/plugin-qmail-validate  <<END_OF_TEST_RESULTS
 451 4.3.0 Could not change to the qmail directory.^M
 553 5.1.0 Sorry, your envelope sender is in my badmailfrom list.^M
@@ -1997,6 +2228,7 @@ EOF
 
 rm -f $tmp/rules $tmp/list $tmp/atlist
 }
+vecho Running test tests/rules-list 
 run_compare_test tests/rules-list  <<END_OF_TEST_RESULTS
 553 DD^M
 250 LIST^M
@@ -2031,6 +2263,7 @@ EOF
 
 rm -f $tmp/patterns
 }
+vecho Running test tests/patterns-general 'xwordx'
 run_compare_test tests/patterns-general 'xwordx' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -2038,6 +2271,7 @@ run_compare_test tests/patterns-general 'xwordx' <<END_OF_TEST_RESULTS
 554 This message contains prohibited content^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/patterns-general 'word at the beginning'
 run_compare_test tests/patterns-general 'word at the beginning' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -2045,6 +2279,7 @@ run_compare_test tests/patterns-general 'word at the beginning' <<END_OF_TEST_RE
 554 This message contains prohibited content^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/patterns-general 'last word'
 run_compare_test tests/patterns-general 'last word' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -2052,6 +2287,7 @@ run_compare_test tests/patterns-general 'last word' <<END_OF_TEST_RESULTS
 554 This message contains prohibited content^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/patterns-general 'middle word middle'
 run_compare_test tests/patterns-general 'middle word middle' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -2059,6 +2295,7 @@ run_compare_test tests/patterns-general 'middle word middle' <<END_OF_TEST_RESUL
 554 This message contains prohibited content^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/patterns-general 'word'
 run_compare_test tests/patterns-general 'word' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -2066,6 +2303,7 @@ run_compare_test tests/patterns-general 'word' <<END_OF_TEST_RESULTS
 554 This message contains prohibited content^M
 END_OF_TEST_RESULTS
 
+vecho Running test tests/patterns-general 'xord'
 run_compare_test tests/patterns-general 'xord' <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
@@ -2101,6 +2339,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/imapfront-auth-login 
 run_compare_test tests/imapfront-auth-login  <<END_OF_TEST_RESULTS
 + VXNlcm5hbWU6^M
 + UGFzc3dvcmQ6^M
@@ -2125,6 +2364,7 @@ QUIT
 QUIT AGAIN
 EOF
 }
+vecho Running test tests/pop3front-auth 
 run_compare_test tests/pop3front-auth  <<END_OF_TEST_RESULTS
 +OK ^M
 -ERR Syntax error^M
@@ -2160,6 +2400,7 @@ MAIL FROM:<a@example.com> SIZE=124
 RCPT TO:<nobody@nowhere>
 EOF
 }
+vecho Running test tests/smtpfront-databytes 
 run_compare_test tests/smtpfront-databytes  <<END_OF_TEST_RESULTS
 250-local.host^M
 250-SIZE 0^M
@@ -2212,6 +2453,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-header-add 
 run_compare_test tests/rules-header-add  <<END_OF_TEST_RESULTS
 250 Sender='a@example.com'.^M
 250 K1^M
@@ -2245,6 +2487,7 @@ c
 d
 EOF
 }
+vecho Running test tests/smtpfront-maxnotimpl 
 run_compare_test tests/smtpfront-maxnotimpl  <<END_OF_TEST_RESULTS
 500 5.5.1 Not implemented.^M
 503-5.5.0 Too many unimplemented commands.^M
@@ -2284,6 +2527,7 @@ DATA
 .
 EOF
 }
+vecho Running test tests/smtpfront-bad-bounce 
 run_compare_test tests/smtpfront-bad-bounce  <<END_OF_TEST_RESULTS
 250 Sender='notbounce@example.com'.^M
 250 Recipient='addr1@example.com'.^M
@@ -2341,6 +2585,7 @@ EOF
 
 unset CVM_SASL_PLAIN
 }
+vecho Running test tests/smtpfront-auth-plain 
 run_compare_test tests/smtpfront-auth-plain  <<END_OF_TEST_RESULTS
 504 Unrecognized authentication mechanism.^M
 250 Sender='user@example.com'.^M
@@ -2396,6 +2641,7 @@ EOF
 
 rm -f $tmp/rules $tmp/list.cdb $tmp/atlist.cdb
 }
+vecho Running test tests/rules-cdb 
 run_compare_test tests/rules-cdb  <<END_OF_TEST_RESULTS
 250 LIST^M
 553 DD^M
@@ -2426,6 +2672,7 @@ EOF
 
 rm -f $tmp/rules
 }
+vecho Running test tests/rules-negate 
 run_compare_test tests/rules-negate  <<END_OF_TEST_RESULTS
 250 B^M
 250 A^M
@@ -2472,6 +2719,7 @@ EOF
 
 rm -f $tmp/patterns
 }
+vecho Running test tests/patterns-after 
 run_compare_test tests/patterns-after  <<END_OF_TEST_RESULTS
 250 Sender=''.^M
 250 Recipient='nobody@example.com'.^M
